@@ -1,19 +1,26 @@
 
 #' The file dumping logger.
 #' 
-#' The file dumping logger dumps the most recent version of a dataset to csv 
-#' in a directory of choice. 
+#' The file dumping logger dumps the most recent version of a dataset to csv in
+#' a directory of choice. 
 #' 
 #' @section Creating a logger:
 #' 
-#' \code{filedump$new(dir=file.path(tempdir(),"timber"), prefix="step\%03d.csv", verbose=TRUE)}
+#' \code{filedump$new(dir=file.path(tempdir(),"filedump"), filename="\%sstep\%03d.csv",verbose=TRUE)}
 #' \tabular{ll}{
-#'   \code{dir}\tab Where to write the file dumps.\cr
-#'   \code{filename}\tab filename template, used with \code{\link{sprintf}} 
-#'      to create a file name.\cr
-#'   \code{verbose}\tab toggle verbosity
+#'   \code{dir}\tab \code{[character]} Directory location to write the file dumps.\cr
+#'   \code{filename}\tab \code{[character]} Template, used to create file names.
+#'                       to create a file name.\cr
+#'   \code{verbose}\tab \code{[logical]} toggle verbosity.
 #' }
 #' 
+#' File locations are created with \code{file.path(dir, file)}, where
+#' \code{file} is generated as \code{sprintf(filename, DATA, STEP)}. In
+#' interactive sessions \code{DATA=""}. In sessions where a script is executed
+#' using \code{\link{run_file}}, \code{DATA} is the name of the R object being
+#' tracked or the \code{label} provided with \code{\link{start_log}}.
+#' \code{STEP} a number that increases at each dump.
+#'
 #' @section Dump options: 
 #' 
 #' \code{$dump(...)}
@@ -34,7 +41,16 @@
 #' @docType class
 #' @format An \code{R6} class object.
 #' 
-#' 
+#' @examples
+#' logger <- filedump$new()
+#'
+#' out <- women %L>%
+#'   start_log(logger) %L>%
+#'   within(height <- height * 2) %L>%
+#'   within(height <- height * 3) %L>%
+#'   dump_log()
+#' dir(file.path(tempdir(),"filedump"))
+#'
 #' 
 #' @family loggers
 #' @export
@@ -44,8 +60,9 @@ filedump <- R6Class("filedump"
     , dir = NULL
     , verbose = NULL
     , filename = NULL
-    , initialize = function(dir = file.path(tempdir(), "timber")
-       , filename="step%03d.csv", verbose = TRUE){
+    , label=NULL
+    , initialize = function(dir = file.path(tempdir(),"filedump")
+       , filename="%sstep%03d.csv", verbose = TRUE){
       self$n <- 0
       self$dir <- dir
       if (!dir.exists(dir)){
@@ -58,19 +75,21 @@ filedump <- R6Class("filedump"
       self$filename <- filename
     }
     , add = function(meta, input, output){
-        outname <- file.path(self$dir,sprintf(self$filename,self$n))
+        prefix <- if (is.null(self$label)) "" else paste0(self$label,"_")
+        outname <- file.path(self$dir, sprintf(self$filename, prefix, self$n))
         if (self$n == 0)
           write.csv(input, file=outname, row.names=FALSE)
         self$n <- self$n + 1
-        outname <- file.path(self$dir,sprintf(self$filename,self$n))
+        outname <- file.path(self$dir, sprintf(self$filename, prefix, self$n))
         write.csv(output, file=outname, row.names=FALSE)
     }
     , dump = function(...){
+        
         if ( self$verbose ){
           msgf("Filedumps were written to %s", normalizePath(self$dir))
         }
     }
-   , log.data = function(){
+   , logdata = function(){
        # this crashes covr
        # if (!dir.exists(self$dir)){
        #   stopf("The directory %s does not exist.",self$dir)
